
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '36.3.0',
    'branch_nick': 'release-36',
    'revision_id': '681dff60333b2f0b7d3f0b1eb7bf42ccc5f15053',
    'revno': 13473
}
